#ifndef _nsCFHChannel_h_
#define _nsCFHChannel_h_

/*
 * $Id: nsCFHChannel.h,v 1.5 2004/01/04 17:57:10 schilz Exp $
 *
 * Copyright (c) 2003-2004  Dr. Thomas Schilz
 *
 * This file is part of MozPHP.
 *
 * MozPHP is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MozPHP is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MozPHP; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "nsIInterfaceRequestor.h"
#include "nsIInterfaceRequestorUtils.h"
#include "nsILoadGroup.h"
#include "nsIStreamListener.h"
#include "nsIURI.h"
#include "nsIFile.h"        /* Solaris/gcc needed this here. */
#include "nsIFileURL.h"
#include "nsIFileChannel.h"
#include "nsIHttpChannel.h"
#include "nsIHttpChannelInternal.h"
#include "nsIUploadChannel.h"
#include "nsIInputStream.h"
#include "nsIProgressEventSink.h"
#include "nsITransport.h"
#include "nsIPostData.h"
#include "nsString.h"
#include "nsCOMPtr.h"
#include "prthread.h"


#define SCHEME "cfh"

#define NS_CFHCHANNEL_CLASSNAME "Combined File and Http Channel"
#define NS_CFHCHANNEL_CONTRACTID "@mozilla.org/network/cfh-channel;1"

#define NS_CFHCHANNEL_CID                       \
{ /* 367df9a2-d558-4ced-9aaa-c4222731be8c */         \
    0x367df9a2,                                      \
    0xd558,                                          \
    0x4ced,                                          \
    {0x9a, 0xaa, 0xc4, 0x22, 0x27, 0x31, 0xbe, 0x8c} \
}


class nsCFHChannel : public nsIFileChannel,
					 public nsIHttpChannel,
					 public nsIHttpChannelInternal,
                     public nsIUploadChannel,
                     public nsIStreamListener,
                     public nsITransportEventSink,
					 public nsIPostData
{
public:
    NS_DECL_ISUPPORTS
    NS_DECL_NSIREQUEST
    NS_DECL_NSICHANNEL
    NS_DECL_NSIFILECHANNEL
    NS_DECL_NSIHTTPCHANNEL
    NS_DECL_NSIHTTPCHANNELINTERNAL
    NS_DECL_NSIUPLOADCHANNEL
    NS_DECL_NSIREQUESTOBSERVER
    NS_DECL_NSISTREAMLISTENER
	NS_DECL_NSITRANSPORTEVENTSINK
	NS_DECL_NSIPOSTDATA

    nsCFHChannel();
    virtual ~nsCFHChannel();

    static NS_METHOD
    Create (nsISupports* aOuter, const nsIID& aIID, void* *aResult);
    
    nsresult Init (nsIURI* uri);

private:
    nsresult EnsureStream();
	nsresult GetClonedFile (nsIFile **);

    nsCOMPtr<nsIURI>                    mURI;
    nsCOMPtr<nsIURI>                    mOriginalURI;
	nsCOMPtr<nsIFileURL>                mFileURL;
    nsCOMPtr<nsIURI>                    mDocumentURI;
	nsCOMPtr<nsIURI>                    mReferrer;
    nsCOMPtr<nsIInterfaceRequestor>     mCallbacks;
	nsCOMPtr<nsIProgressEventSink>      mProgressSink;
    nsCString                           mContentType;
    nsCString                           mContentCharset;
	PRInt32                             mContentLength;
    PRUint32                            mLoadFlags;
    nsCOMPtr<nsILoadGroup>              mLoadGroup;
    nsCOMPtr<nsISupports>               mOwner;
    nsCOMPtr<nsIStreamListener>         mListener;
	nsCOMPtr<nsISupports>               mListenerContext;
    nsresult                            mStatus;
	nsCString							mPostData;
    nsCOMPtr<nsIRequest>                mRequest;
    nsCOMPtr<nsIInputStream>            mStream;
};

#endif // _nsCFHChannel_h_
