/*
 * $Id: nsCFHProtocolHandler.cpp,v 1.4 2004/01/04 17:57:10 schilz Exp $
 *
 * Copyright (c) 2003-2004  Dr. Thomas Schilz
 *
 * This file is part of MozPHP.
 *
 * MozPHP is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MozPHP is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MozPHP; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "nsCFHChannel.h"
#include "nsCFHProtocolHandler.h"

////////////////////////////////////////////////////////////////////////////////

nsCFHProtocolHandler::nsCFHProtocolHandler()
{
    NS_INIT_ISUPPORTS();
}


nsCFHProtocolHandler::~nsCFHProtocolHandler()
{ }


NS_IMPL_THREADSAFE_ISUPPORTS2(nsCFHProtocolHandler,
                              nsIProtocolHandler,
                              nsISupportsWeakReference);


NS_METHOD nsCFHProtocolHandler::Create
	(nsISupports *aOuter, REFNSIID aIID, void **aResult)
{
    if (aOuter)
        return NS_ERROR_NO_AGGREGATION;

	if (!aResult)
		return NS_ERROR_NULL_POINTER;

	*aResult = nsnull;

    nsCFHProtocolHandler* ph = new nsCFHProtocolHandler();

    if (ph == nsnull)
        return NS_ERROR_OUT_OF_MEMORY;

    NS_ADDREF (ph);
	nsresult rv = ph->QueryInterface (aIID, aResult);
    NS_RELEASE (ph);

    return rv;
}


////////////////////////////////////////////////////////////////////////////////
// nsIProtocolHandler methods:
////////////////////////////////////////////////////////////////////////////////

NS_IMETHODIMP nsCFHProtocolHandler::GetScheme (nsACString &result)
{
    result = SCHEME;
    return NS_OK;
}


NS_IMETHODIMP nsCFHProtocolHandler::GetDefaultPort (PRInt32 *result)
{
    *result = -1;        // no port for cfh: URLs
    return NS_OK;
}


NS_IMETHODIMP nsCFHProtocolHandler::GetProtocolFlags (PRUint32 *result)
{
    *result = URI_NOAUTH;
    return NS_OK;
}


NS_IMETHODIMP nsCFHProtocolHandler::NewURI
	(const nsACString &aSpec, const char *aCharset,
	 nsIURI *aBaseURI, nsIURI **result)
{

    nsresult rv;

	nsCOMPtr<nsIFileProtocolHandler> fph =
		do_CreateInstance (NS_NETWORK_PROTOCOL_CONTRACTID_PREFIX "file", &rv);
    if (NS_FAILED (rv)) return rv;

	rv = fph->NewURI (aSpec, aCharset, aBaseURI, result);

    return rv;
}


NS_IMETHODIMP nsCFHProtocolHandler::NewChannel
	(nsIURI* url, nsIChannel* *result)
{

    nsresult rv;
    
    nsCFHChannel* channel;
    rv = nsCFHChannel::Create (nsnull, NS_GET_IID(nsIChannel), (void**)&channel);
    if (NS_FAILED (rv)) return rv;

    rv = channel->Init (url);
    if (NS_FAILED (rv)) {
        NS_RELEASE (channel);
        return rv;
    }

    *result = static_cast<nsIFileChannel*> (channel);
    return NS_OK;
}


NS_IMETHODIMP nsCFHProtocolHandler::AllowPort
	(PRInt32 port, const char *scheme, PRBool *_retval)
{
    // don't override anything.  
    *_retval = PR_FALSE;
    return NS_OK;
}
