#ifndef _nspythontohtmlconv_h_
#define _nspythontohtmlconv_h_

/*
 * $Id: nsPythonToHTMLConv.h,v 1.3 2004/01/05 00:01:59 schilz Exp $
 *
 * Copyright (c) 2004  Dr. Thomas Schilz
 *
 * This file is part of MozPython.
 *
 * MozPython is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MozPython is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MozPython; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "nsIStreamConverter.h"
#include "nsCOMPtr.h"
#include "nsIFactory.h"
#include "nsString.h"
#include "nsNetUtil.h"

// Avoid warning about redefinition of HAVE_UNIT
// #undef HAVE_UINT

#define NS_NSPYTHONTOHTMLCONVERTER_CID \
{ /* 3bb7772e-4ab4-4156-a78b-fc04418d47a1 */ \
	0x3bb7772e, \
	0x4ab4, \
	0x4156, \
	{0xa7, 0x8b, 0xfc, 0x04, 0x41, 0x8d, 0x47, 0xa1} \
}

class nsPythonToHTMLConv : public nsIStreamConverter {
public:
    NS_DECL_ISUPPORTS
    NS_DECL_NSISTREAMCONVERTER
    NS_DECL_NSIREQUESTOBSERVER
    NS_DECL_NSISTREAMLISTENER

    nsPythonToHTMLConv();
    virtual ~nsPythonToHTMLConv();

    // For factory creation.
    static NS_METHOD
    Create(nsISupports *aOuter, REFNSIID aIID, void **aResult) {
        nsresult rv;
        if (aOuter)
            return NS_ERROR_NO_AGGREGATION;

        nsPythonToHTMLConv* _s = new nsPythonToHTMLConv();
        if (_s == nsnull)
            return NS_ERROR_OUT_OF_MEMORY;
        NS_ADDREF(_s);
        rv = _s->QueryInterface(aIID, aResult);
        NS_RELEASE(_s);
        return rv;
    }

	void SetupEnvironment();


private:
	NS_METHOD SendData();


protected:
	nsCOMPtr<nsISupports>		mContext;		// from OnStartRequest
	nsCOMPtr<nsIRequest>		mRequest;		// from OnStartRequest
    nsCOMPtr<nsIStreamListener> mListener;		// final listener (consumer)
    nsString					mBuffer;		// buffer for temporary data
	nsCString					mURI;			// extracted from mRequest
	nsCString					mQuery;			// extracted from mRequest's URL
	nsCString					mPath;			// extracted from mRequest's URL
	nsCString					mFilePath;		// extracted from mRequest's URL
	nsCString					mPostData;		// extracted from channel
};

#endif // _nspythontohtmlconv_h_
