/*
 * $Id: nsPythonToHTMLConvModule.cpp,v 1.2 2004/01/05 00:01:59 schilz Exp $
 *
 * Copyright (c) 2004  Dr. Thomas Schilz
 *
 * This file is part of MozPython.
 *
 * MozPython is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MozPython is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MozPython; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "nsCOMPtr.h"
#include "nsIModule.h"
#include "nsIGenericFactory.h"
#include "nsIServiceManager.h"
#include "nsICategoryManager.h"
#include <prlock.h>

// #define _INC_MATH	// HACK: Avoid inclusion of math.h to prevent inline functions to become multiply defined
#include "nsPythonToHTMLConv.h"

#define TXTPythonToHTML	"?from=text/python&to=text/html"
#define TXTPythonToStar	"?from=text/python&to=*/*"
#define APPPythonToHTML	"?from=application/x-httpd-py&to=text/html"
#define APPPythonToStar	"?from=application/x-httpd-py&to=*/*"

PRLock* PythonLock = PR_NewLock();

nsresult NS_NewNSPythonToHTMLConv(nsPythonToHTMLConv** result);

static NS_IMETHODIMP CreateNewNSPythonToHTMLConvFactory
	(nsISupports *aOuter, REFNSIID aIID, void **aResult)
{
  nsresult rv;

  if (!aResult) {
    return NS_ERROR_NULL_POINTER;
  }
  *aResult = nsnull;

  if (aOuter) {
    return NS_ERROR_NO_AGGREGATION;
  }

  nsPythonToHTMLConv *inst;
  
  inst = new nsPythonToHTMLConv();
  if (!inst) return NS_ERROR_OUT_OF_MEMORY;

  NS_ADDREF(inst);
  rv = inst->QueryInterface(aIID, aResult);
  NS_RELEASE(inst);

  return rv;
}


static NS_METHOD nsRegistrationProc
	(nsIComponentManager *aCompMgr, nsIFile *aPath,
	 const char *registryLocation, const char *componentType,
	 const nsModuleComponentInfo *info)
{
	nsresult rv;
	nsXPIDLCString previous;

	nsCOMPtr<nsICategoryManager> catman =
		do_GetService(NS_CATEGORYMANAGER_CONTRACTID, &rv);
	if (NS_FAILED(rv)) return rv;

	rv = catman->AddCategoryEntry (
			NS_ISTREAMCONVERTER_KEY, TXTPythonToHTML, "x",
            PR_FALSE, PR_TRUE, getter_Copies(previous));
    if (NS_FAILED(rv)) return rv;

	rv = catman->AddCategoryEntry (
			NS_ISTREAMCONVERTER_KEY, TXTPythonToStar, "x",
            PR_FALSE, PR_TRUE, getter_Copies(previous));
    if (NS_FAILED(rv)) return rv;

	//
	// The following entries are nessecary for Mozilla 1.5 under Linux:
	//
	rv = catman->AddCategoryEntry (
			NS_ISTREAMCONVERTER_KEY, APPPythonToHTML, "x",
            PR_FALSE, PR_TRUE, getter_Copies(previous));
    if (NS_FAILED(rv)) return rv;

	rv = catman->AddCategoryEntry (
			NS_ISTREAMCONVERTER_KEY, APPPythonToStar, "x",
            PR_FALSE, PR_TRUE, getter_Copies(previous));
    if (NS_FAILED(rv)) return rv;

	return NS_OK;
}


// The list of components we register
static const nsModuleComponentInfo components[] =
{
    { "NSTXTPythonToHTMLConverter",
      NS_NSPYTHONTOHTMLCONVERTER_CID,
      NS_ISTREAMCONVERTER_KEY TXTPythonToHTML,
      CreateNewNSPythonToHTMLConvFactory,
      nsRegistrationProc
	},
    { "NSTXTPythonToStarConverter",
      NS_NSPYTHONTOHTMLCONVERTER_CID,
      NS_ISTREAMCONVERTER_KEY TXTPythonToStar,
      CreateNewNSPythonToHTMLConvFactory,
      nsRegistrationProc
	},
    { "NSAPPPythonToHTMLConverter",
      NS_NSPYTHONTOHTMLCONVERTER_CID,
      NS_ISTREAMCONVERTER_KEY APPPythonToHTML,
      CreateNewNSPythonToHTMLConvFactory,
      nsRegistrationProc
	},
    { "NSAPPPythonToStarConverter",
      NS_NSPYTHONTOHTMLCONVERTER_CID,
      NS_ISTREAMCONVERTER_KEY APPPythonToStar,
      CreateNewNSPythonToHTMLConvFactory,
      nsRegistrationProc
	}
};

NS_IMPL_NSGETMODULE(nsPythonToHTMLModule, components);
